@@ -10,7 +10,7 @@ use Cwd;
 use File::Path;
 our @ISA = qw( Module::Build );
 
-our $VERSION ='0.44';
+our $VERSION ='0.45';
 
 sub process_xs_files {
 	my $self = shift;
@@ -53,17 +53,17 @@ sub ACTION_clean {
     my $self = shift;
     $self->SUPER::ACTION_clean;
     File::Path::remove_tree('BCM2835/buildlib') if -d 'BCM2835/buildlib';
-    unlink('mylib/lib/libwiringPiStatic.a');
-	unlink('mylib/lib/libwiringPiDevStatic.a');
+    #unlink('mylib/lib/libwiringPiStatic.a');
+	#unlink('mylib/lib/libwiringPiDevStatic.a');
     unlink('mylib/lib/libbcm2835Static.a');
 	unlink('suidbin/hipi-i2c');
 	unlink('suidbin/hipi-pud');
-    chdir('Wiring/src/wiringPi');
-    system('make clean');
-    chdir('../../../');
-	chdir('Wiring/src/devLib');
-    system('make clean');
-    chdir('../../../');
+    #chdir('Wiring/src/wiringPi');
+    #system('make clean');
+    #chdir('../../../');
+	#chdir('Wiring/src/devLib');
+    #system('make clean');
+    #chdir('../../../');
 }
 
 sub ACTION_build {
@@ -72,7 +72,7 @@ sub ACTION_build {
     $self->hipi_do_update;
     $self->hipi_do_depends;
     $self->hipi_do_wx;
-	$self->hipi_build_wiring_library;
+	#$self->hipi_build_wiring_library;
     $self->hipi_build_bcm2835_library;
     $self->hipi_build_xs;
     $self->hipi_build_data;
@@ -159,14 +159,14 @@ sub hipi_do_depends {
         libperl-dev
         libio-epoll-perl
 		libwebkitgtk-1.0-0
+		raspi-gpio
+		wiringpi
     );
 	
-	
 	if ( $self->hipi_build_target eq 'wheezy') {
         push @debs, ( 'libthreads-perl','libthreads-shared-perl','libthread-queue-perl' );
     }
-    
-    
+        
 #   libdbd-pg-perl
 #	libdbd-mysql-perl
 #	libdbd-sqlite3-perl
@@ -291,7 +291,7 @@ sub hipi_build_xs {
         { name => 'I2C',  version => $VERSION, autopath => 'HiPi/Device/I2C', libs => '' },
         { name => 'SPI',  version => $VERSION, autopath => 'HiPi/Device/SPI', libs => '' },
         { name => 'BCM2835', version => $VERSION, autopath => 'HiPi/BCM2835', libs => '-Lmylib/lib -lbcm2835Static' },
-        { name => 'Wiring',  version => $VERSION, autopath => 'HiPi/Wiring',  libs => '-Lmylib/lib -lwiringPiStatic -lwiringPiDevStatic -lpthread' },
+        { name => 'Wiring',  version => $VERSION, autopath => 'HiPi/Wiring',  libs => '-lwiringPi -lwiringPiDev' },
     );
     
     #----------------------------------------------
@@ -432,7 +432,7 @@ sub hipi_install_scriptfiles {
     }
     
     # install plain executables
-    for my $fname ( qw( hipi-control-gui hipi-expin hipi-install hipi-upgrade hipi-gpio) ) {
+    for my $fname ( qw( hipi-control-gui hipi-expin hipi-install hipi-upgrade ) ) {
         $self->log_info(qq(Installing $fname\n));
         my $src = qq(userbin/$fname);
         my $tgt = qq(/usr/local/bin/$fname);
