@@ -2,7 +2,7 @@
 # Package       HiPi::Apps::Control::Panel::GPIODEV
 # Description:  Base for Device panels
 # Created       Wed Feb 27 23:09:33 2013
-# SVN Id        $Id: GPIODEV.pm 3 2015-03-12 01:07:32Z Mark Dootson $
+# SVN Id        $Id: GPIODEV.pm 71 2016-03-15 16:22:29Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -23,7 +23,7 @@ use HiPi::Wx::ValidatedCheckBox;
 use HiPi::Language;
 use HiPi::Wx::ValidatedText;
 use HiPi::Apps::Control::GroupDialog;
-use HiPi::Utils;
+use HiPi::Utils qw( uses_device_tree );
 use Wx::Event( qw( EVT_BUTTON EVT_CHECKBOX EVT_LIST_ITEM_SELECTED EVT_LIST_ITEM_DESELECTED) );
 use Try::Tiny;
 use HiPi::Device::GPIO;
@@ -47,7 +47,7 @@ sub new {
     #------------------------------------------------------
     my $checkdev = HiPi::Wx::ValidatedCheckBox->new($self, t('Allow Group Access To Devices'),  $vdata, 'udevactive');
     my $grp_label = Wx::StaticText->new($self, wxID_ANY, t('Group Name'));
-    my $grp = HiPi::Wx::ValidatedText->new($self, '', $vdata, 'udevgroup', wxTE_READONLY|wxALIGN_RIGHT);
+    my $grp = HiPi::Wx::ValidatedText->new($self, '', $vdata, 'udevgroup', wxTE_READONLY|wxALIGN_RIGHT);    
     $self->group($grp);
     my $grpbutton = Wx::Button->new($self, wxID_ANY, '...', wxDefaultPosition, [25,-1]);
     my $list = HiPi::Apps::Control::Panel::GPIODEV::List->new($self, $vdata);
@@ -66,6 +66,11 @@ sub new {
     my $btnedge = Wx::Button->new($self, wxID_ANY, 'Edge', wxDefaultPosition, [60, -1]);
     $self->btnedge($btnedge);
     
+    if( uses_device_tree ){
+        $grp->Enable(0);
+        $checkdev->Enable(0);
+    }
+    
     
     #------------------------------------------------------
     # Events
