@@ -2,7 +2,7 @@
 # Package       HiPi::Apps::Control::Panel::W1
 # Description:  Base for Device panels
 # Created       Wed Feb 27 23:09:33 2013
-# SVN Id        $Id: W1.pm 3 2015-03-12 01:07:32Z Mark Dootson $
+# SVN Id        $Id: W1.pm 71 2016-03-15 16:22:29Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -21,7 +21,7 @@ use Wx qw( :sizer :id :misc :textctrl );
 use HiPi::Apps::Control::Data::DeviceW1;
 use HiPi::Language;
 use Try::Tiny;
-use HiPi::Utils;
+use HiPi::Utils qw( uses_device_tree );
 use HiPi::Wx::ValidatedCheckBox;
 use Wx::Event qw( EVT_CHECKBOX );
 
@@ -43,6 +43,10 @@ sub new {
     my $modules  = HiPi::Wx::ValidatedCheckBox->new($self, t('W1 Kernel Modules Loaded'),  $vdata, 'loaded');
     my $list = HiPi::Apps::Control::Panel::W1::List->new($self, $vdata);
     
+    if (uses_device_tree) {
+        $modules->Enable(0);
+    }
+    
     #------------------------------------------------------
     # Events
     #------------------------------------------------------
