@@ -2,7 +2,7 @@
 # Package       HiPi::Device
 # Description:  Base class for system devices
 # Created       Sat Dec 01 18:34:18 2012
-# SVN Id        $Id: Device.pm 3 2015-03-12 01:07:32Z Mark Dootson $
+# SVN Id        $Id: Device.pm 71 2016-03-15 16:22:29Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it
 #               under the terms of the GNU General Public License as published by the
@@ -20,6 +20,7 @@ use warnings;
 use parent qw( HiPi::Class );
 use HiPi;
 use HiPi::Constant qw( :raspberry );
+use HiPi::Utils qw( :all );
 use Carp;
 
 __PACKAGE__->create_accessors( qw( devicename ) );
@@ -50,6 +51,11 @@ sub modules_are_loaded {
 
 sub unload_modules {
     my $class = shift;
+    if ( uses_device_tree ) {
+        warn q(The uses the device tree to load device modules at boot time);
+        return;
+    }
+    
     my @modules = $class->get_module_info();
     return unless ( @modules );
     for (my $i = @modules - 1; $i >=0; $i--) {
@@ -63,6 +69,10 @@ sub unload_modules {
 
 sub load_modules {
     my ( $class, $forceunload ) = @_;
+    if ( uses_device_tree ) {
+        warn q(The uses the device tree to load device modules at boot time);
+        return;
+    }
     my @modules  = $class->get_module_info();
     return unless ( @modules );
     
