@@ -2,7 +2,7 @@
 # Package       HiPi::Device::I2C
 # Description:  Wrapper for I2C communucation
 # Created       Fri Nov 23 13:55:49 2012
-# SVN Id        $Id: I2C.pm 71 2016-03-15 16:22:29Z Mark Dootson $
+# SVN Id        $Id: I2C.pm 78 2016-03-29 13:53:19Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -27,7 +27,7 @@ use HiPi::Constant qw( :raspberry );
 use HiPi::Utils qw( is_raspberry );
 use Try::Tiny;
 
-our $VERSION ='0.44';
+our $VERSION ='0.45';
 
 __PACKAGE__->create_accessors( qw ( fh fno address i2cbuffer busmode ) );
 
@@ -253,7 +253,8 @@ sub bus_write_bits {
     while( $bytecount ) {
         my $byte = 0;
         for(my $i = 0; $i < 8; $i++ ) {
-            $byte += ( $bits[$i] << $i );   
+            my $bit = shift @bits;
+            $byte += ( $bit << $i ); 
         }
         push(@bytes, $byte);
         $bytecount --;
