@@ -2,7 +2,7 @@
 # Package       HiPi::Interface::HTBackpackV2
 # Description:  HobbyTronics BackpackV2 LCD Controller
 # Created       Sat Nov 24 20:46:14 2012
-# SVN Id        $Id: HTBackpackV2.pm 1445 2013-03-17 03:59:03Z Mark Dootson $
+# SVN Id        $Id: HTBackpackV2.pm 22 2016-03-04 21:38:30Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -18,7 +18,6 @@ package HiPi::Interface::HTBackpackV2;
 use strict;
 use warnings;
 use parent qw( HiPi::Interface::HD44780 );
-use feature qw( switch );
 use Carp;
 use HiPi::Constant qw( :raspberry );
 
@@ -238,34 +237,25 @@ sub update_baudrate {
     return unless $self->backend eq 'serialrx';
     my $baud = $self->device->baudrate;
     my $bflag;
-    given( $baud ) {
-        when( [ 2400 ] ) {
-            $bflag = HTV2_BAUD_2400;
-        }
-        when( [ 4800 ] ) {
-            $bflag = HTV2_BAUD_4800;
-        }
-        when( [ 9600 ] ) {
-            $bflag = HTV2_BAUD_9600;
-        }
-        when( [ 14400 ] ) {
-            $bflag = HTV2_BAUD_14400;
-        }
-        when( [ 19200 ] ) {
-            $bflag = HTV2_BAUD_19200;
-        }
-        when( [ 28800 ] ) {
-            $bflag = HTV2_BAUD_28800;
-        }
-        when( [ 57600 ] ) {
-            $bflag = HTV2_BAUD_57600;
-        }
-        when( [ 115200 ] ) {
-            $bflag = HTV2_BAUD_115200;
-        }
-        default {
-            croak(qq(The baudrate of the serial device is not supported by the LCD controller));
-        }
+    
+    if ($baud == 2400) {
+        $bflag = HTV2_BAUD_2400;
+    } elsif ($baud == 4800) {
+        $bflag = HTV2_BAUD_4800;
+    } elsif ($baud == 9600) {
+        $bflag = HTV2_BAUD_9600;
+    } elsif ($baud == 14400) {
+        $bflag = HTV2_BAUD_14400;
+    } elsif ($baud == 19200) {
+        $bflag = HTV2_BAUD_19200;
+    } elsif ($baud == 28800) {
+        $bflag = HTV2_BAUD_28800;
+    } elsif ($baud == 57600) {
+        $bflag = HTV2_BAUD_57600;
+    } elsif ($baud == 115200) {
+        $bflag = HTV2_BAUD_115200;
+    } else {
+        croak(qq(The baudrate of the serial device is not supported by the LCD controller));
     }
     
     $self->send_htv2_command( HTV2_CMD_BAUD_RATE, $bflag );
