@@ -2,7 +2,7 @@
 # Package       HiPi::Interface::MPL3115A2
 # Description:  Interface to MPL3115A2 precision Altimeter
 # Created       Wed Mar 13 08:56:53 2013
-# SVN Id        $Id: MPL3115A2.pm 3 2015-03-12 01:07:32Z Mark Dootson $
+# SVN Id        $Id: MPL3115A2.pm 66 2016-03-15 09:33:14Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -677,5 +677,18 @@ sub os_all_data {
     return ( $altitude, $pressure, $tempert );    
 }
 
+sub sea_level_pressure {
+    my( $class, $pressure, $altitude, $temperature, $gravity) = @_;
+    $gravity ||= 9.81;   # acceleratio due to gravity
+    my $dgc    = 287.0; # dry gas constant
+    
+    # Po = ((P * 1000) * Math.exp((g*Zg)/(Rd *  (Tv_avg + 273.15))))/1000;
+    
+    my $result = (($pressure * 10) * exp(($gravity * $altitude)/($dgc *  ($temperature + 273.15))))/10;
+    
+    $result = sprintf("%.2f", $result);
+    return $result;
+}
+
 
 1;
