@@ -2,7 +2,7 @@
 # Package       HiPi::Utils
 # Description:  HiPi Utilities
 # Created       Sun Feb 24 05:16:17 2013
-# SVN Id        $Id: Utils.pm 71 2016-03-15 16:22:29Z Mark Dootson $
+# SVN Id        $Id: Utils.pm 78 2016-03-29 13:53:19Z Mark Dootson $
 # Copyright:    Copyright (c) 2013-2015 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -22,7 +22,7 @@ use base qw( Exporter );
 use XSLoader;
 use HiPi::RaspberryPi qw( :all );
 
-our $VERSION ='0.44';
+our $VERSION ='0.45';
 
 our $defaultuser = 'pi';
 
@@ -109,9 +109,13 @@ sub cat_file {
     my $filepath = shift;
     require HiPi;
     return '' unless is_raspberry;
-    my $rval = HiPi::qx_sudo(qq(/bin/cat $filepath));
-    if($?) {
-        croak qq(reading file $filepath failed : $!);
+    my $rval = '';
+    {
+        local $ENV{PATH} = '/bin:/usr/bin:/usr/local/bin';
+        $rval = HiPi::qx_sudo(qq(/bin/cat $filepath));
+        if($?) {
+            croak qq(reading file $filepath failed : $!);
+        }
     }
     return $rval;
 }
